<?php

namespace App\Http\Controllers;

use App\Models\User;
use Illuminate\Http\Request;
use Spatie\Permission\Models\Role;
use App\Http\Requests\StoreUserRequest;
use App\Http\Requests\UpdateUserRequest;
use Illuminate\Support\Facades\Auth;
use Yajra\Datatables\Datatables;
use App\Models\UserMobileProfile;
use App\Models\MobUserLocation;
use App\Models\Contact;
use DB;

class UsersController extends Controller
{
    /**
     * Display all users
     * 
     * @return \Illuminate\Http\Response
     */
     public $user;
    

    public function __construct()
    {
        $this->middleware('auth');
        $this->middleware(function ($request, $next) { 
         $user = User::find(Auth::User()->id);
        if($user->hasPermissionTo('users'))
        {
            return $next($request);
        }else
        {
            return abort(401);
        }
        //return $next($request);
       });

    }
    public function index() 
    {
       // $users = User::latest()->paginate(10);

        //return view('users.index', compact('users'));
        return view('users.index',[]);
    }

    /**
     * Show form for creating user
     * 
     * @return \Illuminate\Http\Response
     */
    public function create() 
    {
        
        return view('users.create',[
            'roles' => Role::where("name",'!=','Super Admin')->get()
            ]
        );
    }

    /**
     * Store a newly created user
     * 
     * @param User $user
     * @param StoreUserRequest $request
     * 
     * @return \Illuminate\Http\Response
     */
    public function store(User $user, StoreUserRequest $request) 
    {
        //For demo purposes only. When creating user or inviting a user
        // you should create a generated random password and email it to the user
       $user =  $user->create($request->all());
        $user->syncRoles($request->get('role'));

        return redirect()->route('users.index')
            ->withSuccess(__('User created successfully.'));
    }

    /**
     * Show user data
     * 
     * @param User $user
     * 
     * @return \Illuminate\Http\Response
     */
    public function show(User $user) 
    {
        return view('users.show', [
            'user' => $user
        ]);
    }

    /**
     * Edit user data
     * 
     * @param User $user
     * 
     * @return \Illuminate\Http\Response
     */
    public function edit(User $user) 
    {
        return view('users.edit', [
            'user' => $user,
            'userRole' => $user->roles->pluck('name')->toArray(),
            'roles' => Role::where("name",'!=','Super Admin')->get()
        ]);
    }

    /**
     * Update user data
     * 
     * @param User $user
     * @param UpdateUserRequest $request
     * 
     * @return \Illuminate\Http\Response
     */
    public function update(User $user, UpdateUserRequest $request) 
    {
        $user->update($request->validated());

        $user->syncRoles($request->get('role'));

        return redirect()->route('users.index')
            ->withSuccess(__('User updated successfully.'));
    }

    /**
     * Delete user data
     * 
     * @param User $user
     * 
     * @return \Illuminate\Http\Response
     */
    public function destroy(User $user) 
    {
        $user->delete();

        return redirect()->route('users.index')
            ->withSuccess(__('User deleted successfully.'));
    }
    /**
     * Delete user data
     * 
     * @param Request $request
     * 
     * @return \Illuminate\Http\Response
     */
     public function DelUser(Request $request) 
    {
        if($request->id!='')
        {
            $us = User::where("id",$request->id)->delete();
            if($us)
            {
                DB::table("model_has_roles")->where("model_id",$request->id)->delete();
                DB::table("model_has_permissions")->where("model_id",$request->id)->delete();
                echo "1";
            }else
            {
                echo "0";
            }
            
        }
        return "";
    }
    
    /**
     * list user in datatable
     * 
     * @param Request $request
     * 
     * @return Datatable json object
     */
    public function tableList(Request $request)
    {
        //dd(User::with('role')->get()->toArray());
        //$users = User::where("user_type",'web');
        $users = User::with('roles')->where("user_type",'web')->where("user_role",'normal');
       // $users = User::join("model_has_roles","model_has_roles.modal_id",'=',"users.id")->where("users.user_type",'web');
            return Datatables::of($users)    
            ->addColumn('action', function ($user) {

                 //$hidetake = "display:none;";
                 $hidetake = "";
                 $edit = route('users.edit', $user->id);
                 
                 
                $chk = ($user->status=='1') ? "checked":"";
                $b = '<a  href="'.$edit.'" class="btn btn-sm btn-primary"><i class="fa fa-edit"></i></a> ';
                $b.= '<a onclick="del_client('.$user->id.')" href="javascript:;" class="btn btn-sm btn-danger danger-alert"><i class="fa fa-trash"></i></a> ';                                
                $b.= '<a style="'.$hidetake.'" onclick="login_client('.$user->id.')" href="javascript:;" class="btn btn-sm btn-info info-alert"><i class="fas fa fa-power-off"></i></a> ';
                
                
                //$b.='<div class="my_switch make-switch"> <input type="checkbox" name="user_st" value="'.$user->id.'" checked /></div>';
                return $b;
            })
            ->addColumn('roles',function($camp) {
                $roles = $camp->roles->pluck('name');
                
              return implode(',',$roles->all());
            })
            ->editColumn('created_at',function($camp) {
                
              return $camp->created_at->format("Y-m-d h:i a");
            })
            ->removeColumn('password')
            ->rawColumns(['action'])
           // ->removeColumn('status')
            ->make(true);
    }
    
    public function tablemobList(Request $request)
    {
        $users = User::where("user_type",'mobile');
       // $users = User::join("model_has_roles","model_has_roles.modal_id",'=',"users.id")->where("users.user_type",'web');
            return Datatables::of($users)    
            ->addColumn('action', function ($user) {

                 //$hidetake = "display:none;";
                 $hidetake = "";
                 $edit = route('users.edit', $user->id);
                 $profile = route("mobUserprofile")."?id=".$user->id;
                 $cons = route("mobUsercontacts")."?id=".$user->id;
                $chk = ($user->status=='1') ? "checked":"";
                $b = '<a  href="javascript:;" onclick="edit_user('.$user->id.')" class="btn btn-sm btn-primary"><i class="fa fa-edit"></i></a> ';
                $b.= '<a onclick="del_client('.$user->id.')" href="javascript:;" class="btn btn-sm btn-danger danger-alert"><i class="fa fa-trash"></i></a> ';                                
                $b.= '<a href="'.$profile.'" title="View Profile" class="btn btn-sm btn-info info-alert"><i class="fas fa fa-id-badge"></i></a> ';
                $b.= '<a href="'.$cons.'" title="View Contacts" class="btn btn-sm btn-warning warning-alert"><i class="fas fa fa-users"></i></a> ';
                
                
                //$b.='<div class="my_switch make-switch"> <input type="checkbox" name="user_st" value="'.$user->id.'" checked /></div>';
                return $b;
            })
            
            ->editColumn('created_at',function($camp) {
                
              return $camp->created_at->format("Y-m-d h:i a");
            })
            ->removeColumn('password')
            ->rawColumns(['action'])
           // ->removeColumn('status')
            ->make(true);
    }
    
    public function mobUsers(Request $request)
    {
        return view('users.mob-users',[]);
    }
    public function getmobUser(Request $request)
    {
        return User::find($request->id);
    }
    public function saveMobUser(Request $request)
    {
        if($request->user_id=='')
        {
            $userCheck = User::where('email', $request->email)->count();
            if($userCheck>0)
            {
                 return "2";
            }
        }
        
        $user =  new User;
        if($request->user_id!='')
        {
            
            $user = $user->findOrFail($request->user_id);
            
        }
        $user->fill($request->all());
        if($request->password!='')
        {
            
            $user->password = bcrypt($request->password);
            
        }
        $user->user_type="mobile"; 
        if($user->save())
        {
            if($request->user_id=='')
            {
                $prof = new UserMobileProfile;
                $prof->user_id=$user->id;
                $prof->save(); //saving mobile profile
            }
            echo "1";
        }else
        {
            echo "0";
        }
        return "";
    }
    
    public function mobUserprofile(Request $request)
    {
        if(!filter_var($request->id,FILTER_VALIDATE_INT))
        {
             abort(401);   
        }
        
        $profile = UserMobileProfile::where("user_id",$request->id)->first();
       // $profile = UserMobileProfile::where("user_id",$request->id)->first();
        $location = MobUserLocation::where("user_id",$request->id)->first();
        
        if($location==null)
        {
            $location = new \stdClass;
            $location->city = "";
            $location->country = "";
            $location->district = "";
            $location->isoCountryCode = "";
            $location->postalCode = "";
            $location->region = "";
            $location->street = "";
            $location->streetNumber = "";
        }
        
        return view("users.mob-user-profile",["profile"=>$profile,"location"=>$location,"user_id"=>$request->id]);
    }
    
    public function tableconList(Request $request)
    {
        $users = Contact::where("user_id",$request->id);
       // $users = User::join("model_has_roles","model_has_roles.modal_id",'=',"users.id")->where("users.user_type",'web');
            return Datatables::of($users)    
            /*->addColumn('action', function ($user) {

                 //$hidetake = "display:none;";
                 $hidetake = "";
                 $edit = route('users.edit', $user->id);
                 $profile = route("mobUserprofile")."?id=".$user->id;
                 $cons = route("mobUsercontacts")."?id=".$user->id;
                $chk = ($user->status=='1') ? "checked":"";
                $b = '<a  href="javascript:;" onclick="edit_user('.$user->id.')" class="btn btn-sm btn-primary"><i class="fa fa-edit"></i></a> ';
                $b.= '<a onclick="del_client('.$user->id.')" href="javascript:;" class="btn btn-sm btn-danger danger-alert"><i class="fa fa-trash"></i></a> ';                                
                $b.= '<a href="'.$profile.'" title="View Profile" class="btn btn-sm btn-info info-alert"><i class="fas fa fa-id-badge"></i></a> ';
                $b.= '<a href="'.$cons.'" title="View Contacts" class="btn btn-sm btn-warning warning-alert"><i class="fas fa fa-users"></i></a> ';
                
                
                //$b.='<div class="my_switch make-switch"> <input type="checkbox" name="user_st" value="'.$user->id.'" checked /></div>';
                return $b;
            })*/
            
            ->editColumn('created_at',function($camp) {
                
              return $camp->created_at->format("Y-m-d h:i a");
            })
           // ->removeColumn('password')
            ->rawColumns(['action'])
           // ->removeColumn('status')
            ->make(true);
    }
    
    public function mobUsercontacts(Request $request)
    {
        if(!filter_var($request->id,FILTER_VALIDATE_INT))
        {
             abort(401);   
        }
        return view("users.user-contacts",["user_id"=>$request->id]);
    }
}


/*

git clone https://github.com/codeanddeploy/laravel8-authentication-example.git

if your using my previous tutorial navigate your project folder and run composer update



install packages

composer require spatie/laravel-permission
composer require laravelcollective/html

then run php artisan vendor:publish --provider="Spatie\Permission\PermissionServiceProvider"

php artisan migrate

php artisan make:migration create_posts_table

php artisan migrate

models
php artisan make:model Post

middleware
- create custom middleware
php artisan make:middleware PermissionMiddleware

register middleware
- 

routes

controllers

- php artisan make:controller UsersController
- php artisan make:controller PostsController
- php artisan make:controller RolesController
- php artisan make:controller PermissionsController

requests
- php artisan make:request StoreUserRequest
- php artisan make:request UpdateUserRequest

blade files

create command to lookup all routes
- php artisan make:command CreateRoutePermissionsCommand
- php artisan permission:create-permission-routes

seeder for default roles and create admin user
php artisan make:seeder CreateAdminUserSeeder
php artisan db:seed --class=CreateAdminUserSeeder



*/