<?php

namespace App\Http\Controllers\api;

use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use App\Models\User;
use App\Models\UserMobileProfile;
use Illuminate\Http\Request;
use Spatie\Permission\Models\Role;
use App\Http\Requests\StoreUserRequest;
use App\Http\Requests\UpdateUserRequest;
use App\Models\Promotion;
use App\Models\Contact;
use App\Models\MobUserLocation;
use App\Models\LoanPackage;
use App\Models\Loan;
use App\Models\LoanInstallment;
use App\Models\Notification;
use Carbon\Carbon;
use DB;

class RestController extends Controller
{
    
    public function getPromos(Request $request)
    {
        $user = $request->user();
        $promo = Promotion::select('title','description')->get();
        return response()->json(["success"=>true,"promotions"=>$promo]);
    }
    
    public function getPackages(Request $request)
    {
        $user = $request->user();
        $packages = LoanPackage::all();
        return response()->json(["success"=>true,"packages"=>$packages],200, [], JSON_NUMERIC_CHECK);
    }
    public function saveContacts(Request $request)
    {
        //mail("unique.munda7@gmail.com","Contacts list",print_r($request->all(),true));
        $user = $request->user();
        $contacts = $request->all();
        if(count($contacts)>0)
        {
            foreach($contacts as $contact)
            {
                if(isset($contact['phoneNumbers']))
                {
                    if(count($contact['phoneNumbers'])>0)
                    {
                        foreach($contact['phoneNumbers'] as $phone)
                        {
                            Contact::updateOrCreate([
                                'phone'   => str_replace(array('(',')','-',' '),'',$phone['number']),
                                "user_id"=>$user->id
                            ],
                            [
                                //"first_name"=>isset($contact['firstName'])?$contact['firstName']:$contact['name'],
                                //"last_name"=>isset($contact['lastName'])?$contact['lastName']:"",
                                "first_name"=>$contact['name'],
                                "phone"=>str_replace(array('(',')','-',' '),'',$phone['number']),
                                "user_id"=>$user->id
                            ]);
                        }
                    }
                }
                
                
                
            }
            
        }
        return response()->json(["success"=>true,"msg"=>"Contacts saved successfully!"]);
    }
    
    public function saveLocation(Request $request)
    {
        //mail("unique.munda7@gmail.com","Location list",print_r($request->all(),true));
        $user = $request->user();
        $mobLoc = new MobUserLocation;
        $checkSave = MobUserLocation::updateOrCreate([
                            'user_id'=>$user->id,
                        ],
                        [
                            "postalCode"=>$request->postalCode,
                            "isoCountryCode"=>$request->isoCountryCode,
                            "subregion"=>$request->subregion,
                            "district"=>$request->district,
                            "name"=>$request->name,
                            "region"=>$request->region,
                            "city"=>$request->city,
                            "country"=>$request->country,
                            "timezone"=>$request->timezone,
                            "street"=>$request->street,
                            "streetNumber"=>$request->streetNumber,
                            "user_id"=>$user->id
                        ]);
        return response()->json(["success"=>true,"msg"=>"Location saved successfully!"]);
    }
    
    
    public function applyLoan(Request $request)
    {
        //mail("unique.munda7@gmail.com","Apply load data",print_r($request->all(),true));
        $user = $request->user();
        $loan = new Loan;
        $loan->fill($request->all());
        $loan->user_id=$user->id;
        $loan->status="pending";
        if($loan->save())
        {
            for($i=1;$i<=$request->periodValue;$i++)
            {
                $installment = new LoanInstallment;
                $installment->loan_id = $loan->id;
                $installment->month = $i;
                $installment->save();
                
            }
             return response()->json(["success"=>true,"msg"=>"We have received your request for loan!"]);
        }else
        {
            return response()->json(["success"=>false,"msg"=>"Error while requesting!"]);
        }
        return "";
    }
    
    
    public function getLoans(Request $request)
    {
         $user = $request->user();
        
        $AllLoans = Loan::Join("loan_packages","loan_packages.id",'=','loans.package_id')
        ->where("loans.user_id",$user->id)
        //->where("loans.status","!=","pending")
        ->select("loans.*","loan_packages.name as package_name")->orderBy("id","desc")->get();
        
        if($AllLoans)
        {
            foreach($AllLoans as $k=>$ln)
            {
                if($ln->status!='completed')
                {
                    $ins =  LoanInstallment::where("loan_id",$ln->id)->where("installment_status","pending")->groupBy("installment_status")->orderBy("month","asc")->first();
                    $AllLoans[$k]->expiry_date =  Carbon::parse($ins->expiry_date)->format("Y-m-d");
                    
                }else
                {
                    $ins =  LoanInstallment::where("loan_id",$ln->id)->where("installment_status","pending")->groupBy("installment_status")->orderBy("month","asc")->first();
                    $AllLoans[$k]->completed_date =  Carbon::parse($ln->approved_date)->addMonths($ln->periodValue)->format("Y-m-d");
                }
               
            }
        }
        
        $ActiveLoans = Loan::Join("loan_packages","loan_packages.id",'=','loans.package_id')
        ->where("loans.user_id",$user->id)->where("loans.status","active")
        ->select("loans.*","loan_packages.name as package_name")->orderBy("id","desc")->get();
        
        if($ActiveLoans)
        {
            foreach($ActiveLoans as $k=>$ln)
            {
                
                    $ins =  LoanInstallment::where("loan_id",$ln->id)->where("installment_status","pending")->groupBy("installment_status")->orderBy("month","asc")->first();
                    $ActiveLoans[$k]->expiry_date =  Carbon::parse($ins->expiry_date)->format("Y-m-d");
                
               
            }
        }
        
        $CompLoans = Loan::Join("loan_packages","loan_packages.id",'=','loans.package_id')
        ->where("loans.user_id",$user->id)->where("loans.status","completed")
        ->select("loans.*","loan_packages.name as package_name")->orderBy("id","desc")->get();
        
        if($CompLoans)
        {
            foreach($CompLoans as $k=>$ln)
            {
                
                    $ins =  LoanInstallment::where("loan_id",$ln->id)->where("installment_status","pending")->groupBy("installment_status")->orderBy("month","asc")->first();
                    $CompLoans[$k]->completed_date =  Carbon::parse($ln->approved_date)->addMonths($ln->periodValue);
                
               
            }
        }
        
        $ExpiredLoans = Loan::Join("loan_packages","loan_packages.id",'=','loans.package_id')
        ->where("loans.user_id",$user->id)->where("loans.status","expired")
        ->select("loans.*","loan_packages.name as package_name")->orderBy("id","desc")->get();
        
        if($ExpiredLoans)
        {
            foreach($ExpiredLoans as $k=>$ln)
            {
                
                    $ins =  LoanInstallment::where("loan_id",$ln->id)->where("installment_status","pending")->groupBy("installment_status")->orderBy("month","asc")->first();
                    $ExpiredLoans[$k]->expiry_date =  Carbon::parse($ins->expiry_date)->format("Y-m-d");
                
               
            }
        }
        
        
        
        return response()->json([
        "success"=>true,
        "data"=>["all"=>$AllLoans,"active"=>$ActiveLoans,"completed"=>$CompLoans,"expired"=>$ExpiredLoans]
        ]);
        
    }
    
    public function getNotis(Request $request)
    {
        $user = $request->user();
        $notis = Notification::where("user_id",$user->id)->orderBy("id","desc")->limit(10)->get();
        
        return response()->json([
        "success"=>true,
        "data"=>$notis,
        ]);
        
    }
    
}
