@extends('layouts.app')

@section('content')

<div class="d-sm-flex align-items-center justify-content-between mb-4">
        <h1 class="h3 mb-0 text-gray-800">Edit role and manage permissions</h1>
            
    </div>
<div class="row">
    <div class="mt-2">
            @include('layouts.partials.messages')
    </div>
    <div class="col-md-12 col-lg-12">
            <div class="card shadow mb-4">
                <div class="card-header py-3">
                    <h6 class="m-0 font-weight-bold text-primary">Roles List</h6>
                </div>
                <div class="card-body">
                        @if (count($errors) > 0)
                            <div class="alert alert-danger">
                                <strong>Whoops!</strong> There were some problems with your input.<br><br>
                                <ul>
                                @foreach ($errors->all() as $error)
                                    <li>{{ $error }}</li>
                                @endforeach
                                </ul>
                            </div>
                        @endif
            
                        <form method="POST" action="{{ route('roles.update', $role->id) }}">
                            @method('patch')
                            @csrf
                            <div class="mb-3">
                                <label for="name" class="form-label">Name</label>
                                <input value="{{ $role->name }}" 
                                    type="text" 
                                    class="form-control" 
                                    name="name" 
                                    placeholder="Name" required>
                            </div>
                            
                            <label for="permissions" class="form-label">Assign Permissions</label>
            
                            <table class="table table-striped">
                                <thead>
                                    <th scope="col" width="1%"><input type="checkbox" name="all_permission"></th>
                                    <th scope="col" width="20%">Name</th>
                                    <th scope="col" width="1%">Guard</th> 
                                </thead>
            
                                @foreach($permissions as $permission)
                                    <tr>
                                        <td>
                                            <input type="checkbox" onchange="checkList()"
                                            name="permission[{{ $permission->user_friendly_name }}]"
                                            value="{{ $permission->user_friendly_name }}"
                                            class='permission'
                                            {{ in_array($permission->user_friendly_name, $rolePermissions) 
                                                ? 'checked'
                                                : '' }}>
                                        </td>
                                        <td>{{ $permission->user_friendly_name }}</td>
                                        <td>{{ $permission->guard_name }}</td>
                                    </tr>
                                @endforeach
                            </table>
            
                            <button type="submit" class="btn btn-primary">Save changes</button>
                            <a href="{{ route('roles.index') }}" class="btn btn-default">Back</a>
                        </form>
                </div>
            </div>
    </div>
</div>
    
    
@endsection

@section('script')
    <script type="text/javascript">
        $(document).ready(function() {
            $('[name="all_permission"]').on('click', function() {
                if($(this).is(':checked')) {
                    $('.permission').each(function() {
                        $(this).prop('checked',true);
                    });
                } else {
                    $('.permission').each(function() {
                        $(this).prop('checked',false);
                    });
                }
                
            });
        });
    </script>
@endsection